3 ms·
I noticed the same thing. Modifying the code to make a simple cast made the code run from 5.6353 sec to 2.3411 sec, but this benchmark still shows very little a
by Nican 14y ago
I noticed the same thing. Modifying the code to make a simple cast made the code run from 5.6353 sec to 2.3411 sec, but this benchmark still shows very little about optimizations.